@@ -155,7 +155,7 @@ use warnings;
 {
     package Doit::Util;
     use Exporter 'import';
-    our @EXPORT; BEGIN { @EXPORT = qw(in_directory new_scope_cleanup copy_stat) }
+    our @EXPORT; BEGIN { @EXPORT = qw(in_directory new_scope_cleanup copy_stat get_sudo_cmd) }
     $INC{'Doit/Util.pm'} = __FILE__; # XXX hack
     use Doit::Log;
 
@@ -221,6 +221,11 @@ use warnings;
 	}
     }
 
+    sub get_sudo_cmd () {
+	return () if $> == 0;
+	return ('sudo');
+    }
+
 }
 
 {
@@ -309,7 +314,7 @@ use warnings;
 {
     package Doit;
 
-    our $VERSION = '0.021_52';
+    our $VERSION = '0.021_53';
 
     sub import {
 	warnings->import;
